# ListHistoryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**history** | [**list[History]**](History.md) | List of history records. Any &#x60;messages&#x60; contained in the response will typically only have &#x60;id&#x60; and &#x60;threadId&#x60; fields populated. | [optional] 
**history_id** | **str** | The ID of the mailbox&#x27;s current history record. | [optional] 
**next_page_token** | **str** | Page token to retrieve the next page of results in the list. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

